%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Create bathymetry 
%%
%% !!! Need to change the bathy grid (line 22) !!!
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear all;
close all
clc

%% Set Min depth.
mind = -10;


%% Path and Grid.
fpath = '/net/wave3/ganeshgopal/WAVE5_DATA/GOM_OI_24DEG/FORCINGS/';
eval(['load ' fpath 'GRID.mat']);
eval(['load ' fpath 'FMT.mat']);


%% ETOPO2 bathy.
[b,xe,ye] = rdbathy;
b = flipud(b')';
b(b>0) = 0;
neg = find(xe<0);
xe(neg) = 360+xe(neg);


%% Plot ETOPO2 bathy in my domain.
dd = 3;
ie = find( xe<=xc(end)+dd & xe>=xc(1)-dd );
je = find( ye<=yc(end)+dd & ye>=yc(1)-dd );
xe = xe(ie); ye = ye(je); b = b(ie,je);
figure(1); imagesc(rot90(b)); colorbar;pause


%% Interpolate bathy on my grid - Median Interpolation.
%% Set size of the box.
radius = 0.05;
%% Select points in a box around the grid point and take the median.
for ic = 1:nxc
  for jc = 1:nyc
    ie = find( (xe<=xc(ic)+radius) & (xe>=xc(ic)-radius) );
    je = find( (ye<=yc(jc)+radius) & (ye>=yc(jc)-radius) );
    tmp = b(ie,je);
    hi(ic,jc) = median(tmp(:));
  end
end
%% Plot
tmp = hi; tmp(tmp==0) = nan;
figure(2); imagesc(rot90(hi)); colorbar;pause


%% OR
%% Interpolate bathy on my grid - 'Nearest' Interpolation.
%% Interpolate
%% hi = interp2(ye,xe,b,yc,xc,'nearest');
%% Plot
%% tmp = hi; tmp(tmp==0) = nan;
%% figure; imagesc(rot90(tmp)); colorbar;


%% Gaussian Smoothing.
%% Set radius
radius = 0.08;
%% Set mask
msk = hi;
msk(msk~=0) = 1;
%% Smooth
hs = interp2gauss(yc,xc,hi,yc,xc,msk,1.,radius,radius);
%% Plot
tmp = hs; tmp(tmp==0) = nan;
figure(3); imagesc(rot90(tmp)); colorbar;pause


%% Round to nearest "res" metres.
hn = mind*round(hs/mind);


%% Limit deepest point.
hn(hn<zf(end)) = zf(end);

%% Limit min depth.
hn(hn > mind) = 0;

%% Set minimum depth to mind.
hn( hn > mind & hn < 0 ) = mind;

%% Plot
tmp = hn; tmp(tmp==0) = nan;
figure(4); imagesc(rot90(tmp)); colorbar;pause

%% No slopes at OB - Mean
%% Save original bathy
hnm = hn;
%% South
hnm(:,1) = mean([hn(:,1) hn(:,2)],2);
hnm(:,2) = mean([hn(:,1) hn(:,2)],2);
%% North
hnm(:,nyc-1) = mean([hn(:,nyc-1) hn(:,nyc)],2);
hnm(:,nyc)   = mean([hn(:,nyc-1) hn(:,nyc)],2);
%% West
hnm(1,:) = mean([hn(1,:)' hn(2,:)'],2);
hnm(2,:) = mean([hn(1,:)' hn(2,:)'],2);
%% East
hnm(nxc-1,:) = mean([hn(nxc-1,:)' hn(nxc,:)'],2);
hnm(nxc,:)   = mean([hn(nxc-1,:)' hn(nxc,:)'],2);
%% Plot
tmp = hnm; tmp(tmp==0) = nan;
figure(5); imagesc(rot90(tmp)); colorbar;


%% Match topography at OB with the layers depths for partial cells
%% North 
for i = 1:nxc
  ic = max(find(zf>hnm(i,nyc)));
  if (length(ic) ~= 0)
    hnm(i,nyc-1) = zf(ic); 
    hnm(i,nyc) = zf(ic); 
  end
end

%% South 
for i = 1:nxc
  ic = max(find(zf>hnm(i,1)));
  if (length(ic) ~= 0)
    hnm(i,1) = zf(ic); 
    hnm(i,2) = zf(ic); 
  end
end
%% West
for j = 1:nyc
  jc = max(find(zf>hnm(1,j)));
  if (length(jc) ~= 0)
    hnm(1,j) = zf(jc); 
    hnm(2,j) = zf(jc); 
  end
end
%% East
for j = 1:nyc
  jc = max(find(zf>hnm(nxc,j)));
  if (length(jc) ~= 0)
    hnm(nxc-1,j) = zf(jc); 
    hnm(nxc,j)   = zf(jc); 
  end
end


%% Edit topography (only edit 2 points from the boundaries!!!!!!!)
figure; hnm = edtopo_obcs(hnm);


%% Save bathymetry in bathymetry.bin
wrslice([fpath 'bathymetry.bin'],hnm,1,fmt,Ieee);
